.. _glossary:

============================
Glossary
============================

.. glossary::

  YAML
     A textual format and syntax for configuration and serialization.
     See the `YAML website <http://yaml.org>`_.
  directive
     A callable that handles a configuration section, populating a
     registry.
